.. _urlrewrite_module:

:mod:`cubicweb_web.views.urlrewrite`
=======================================

.. automodule:: cubicweb_web.views.urlrewrite

    .. autoclass:: URLRewriter
        :show-inheritance:
        :members:

    .. autoclass:: SimpleReqRewriter
        :show-inheritance:
        :members:

    .. autoclass:: SchemaBasedRewriter
        :show-inheritance:
        :members:
